@@ -145,16 +145,19 @@ totem_screenshot_init (TotemScreenshot *screenshot)
 }
 
 GtkWidget *
-totem_screenshot_new (TotemPlugin *screenshot_plugin, GdkPixbuf *screen_image)
+totem_screenshot_new (Totem *totem, TotemPlugin *screenshot_plugin, GdkPixbuf *screen_image)
 {
 	TotemScreenshot *screenshot;
 	GtkContainer *content_area;
-	char *interface_path, *initial_uri;
+	gchar *movie_title, *interface_path, *initial_uri;
 
 	screenshot = TOTEM_SCREENSHOT (g_object_new (TOTEM_TYPE_SCREENSHOT, NULL));
 
+	movie_title = totem_get_short_title (totem);
+
 	/* Create the screenshot widget */
-	initial_uri = totem_screenshot_plugin_setup_file_chooser (N_("Screenshot%d.png"));
+	initial_uri = totem_screenshot_plugin_setup_file_chooser (N_("Screenshot-%s-%d.png"), movie_title);
+	g_free (movie_title);
 	interface_path = totem_plugin_find_file (screenshot_plugin, "gnome-screenshot.ui");
 	screenshot->priv->widget = GNOME_SCREENSHOT_WIDGET (gnome_screenshot_widget_new (interface_path, screen_image, initial_uri));
 	g_free (interface_path);
