@@ -36,6 +36,7 @@
 #include "totem-interface.h"
 #include "totem-time-label.h"
 #include "bacon-video-widget.h"
+#include "gsd-media-keys-window.h"
 
 #define FULLSCREEN_POPUP_TIMEOUT 5
 
@@ -56,6 +57,7 @@ G_MODULE_EXPORT gboolean totem_fullscreen_control_leave_notify (GtkWidget *widge
 struct _TotemFullscreenPrivate {
 	BaconVideoWidget *bvw;
 	GtkWidget        *parent_window;
+	GtkWidget        *osd;
 
 	/* Fullscreen Popups */
 	GtkWidget        *exit_popup;
@@ -144,6 +146,20 @@ totem_fullscreen_theme_changed_cb (GtkIconTheme *icon_theme, TotemFullscreen *fs
 	totem_fullscreen_move_popups (fs);
 }
 
+static void
+totem_fullscreen_composited_changed_cb (GdkScreen *screen, TotemFullscreen *fs)
+{
+	if (gdk_screen_is_composited (screen)) {
+		if (fs->priv->osd == NULL)
+			fs->priv->osd = gsd_media_keys_window_new ();
+	} else {
+		if (fs->priv->osd != NULL) {
+			gtk_widget_destroy (fs->priv->osd);
+			fs->priv->osd = NULL;
+		}
+	}
+}
+
 static void
 totem_fullscreen_window_realize_cb (GtkWidget *widget, TotemFullscreen *fs)
 {
@@ -152,9 +168,13 @@ totem_fullscreen_window_realize_cb (GtkWidget *widget, TotemFullscreen *fs)
 	screen = gtk_widget_get_screen (widget);
 	g_signal_connect (G_OBJECT (screen), "size-changed",
 			  G_CALLBACK (totem_fullscreen_size_changed_cb), fs);
+	g_signal_connect (G_OBJECT (screen), "composited-changed",
+			  G_CALLBACK (totem_fullscreen_composited_changed_cb), fs);
 	g_signal_connect (G_OBJECT (gtk_icon_theme_get_for_screen (screen)),
 			  "changed",
 			  G_CALLBACK (totem_fullscreen_theme_changed_cb), fs);
+
+	totem_fullscreen_composited_changed_cb (screen, fs);
 }
 
 static void
@@ -169,6 +189,29 @@ totem_fullscreen_window_unrealize_cb (GtkWidget *widget, TotemFullscreen *fs)
 					      G_CALLBACK (totem_fullscreen_theme_changed_cb), fs);
 }
 
+static gboolean
+totem_fullscreen_exit_popup_expose_cb (GtkWidget *widget,
+				       GdkEventExpose *event,
+				       TotemFullscreen *fs)
+{
+	GdkScreen *screen;
+	cairo_t *cr;
+
+	screen = gtk_widget_get_screen (widget);
+	if (gdk_screen_is_composited (screen) == FALSE)
+		return FALSE;
+
+	gtk_widget_set_app_paintable (widget, TRUE);
+
+	cr = gdk_cairo_create (gtk_widget_get_window (widget));
+	cairo_set_source_rgba (cr, 1., 1., 1., 0.);
+	cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+	cairo_paint (cr);
+	cairo_destroy (cr);
+
+	return FALSE;
+}
+
 gboolean
 totem_fullscreen_seek_slider_pressed_cb (GtkWidget *widget,
 					 GdkEventButton *event,
@@ -293,6 +336,44 @@ totem_fullscreen_show_popups (TotemFullscreen *fs, gboolean show_cursor)
 	fs->priv->popup_in_progress = FALSE;
 }
 
+void
+totem_fullscreen_show_popups_or_osd (TotemFullscreen *fs,
+				     const char *icon_name,
+				     gboolean show_cursor)
+{
+	GtkAllocation allocation;
+	GdkScreen *screen;
+	GdkWindow *window;
+	GdkRectangle rect;
+	int monitor;
+
+	if (fs->priv->osd == NULL || icon_name == NULL) {
+		totem_fullscreen_show_popups (fs, show_cursor);
+		return;
+	}
+
+	gtk_widget_get_allocation (GTK_WIDGET (fs->priv->bvw), &allocation);
+	gtk_window_resize (GTK_WINDOW (fs->priv->osd),
+			   allocation.height / 8,
+			   allocation.height / 8);
+
+	window = gtk_widget_get_window (GTK_WIDGET (fs->priv->bvw));
+	screen = gtk_widget_get_screen (GTK_WIDGET (fs->priv->bvw));
+	monitor = gdk_screen_get_monitor_at_window (screen, window);
+	gdk_screen_get_monitor_geometry (screen, monitor, &rect);
+
+	if (gtk_widget_get_direction (GTK_WIDGET (fs->priv->bvw)) == GTK_TEXT_DIR_RTL)
+		gtk_window_move (GTK_WINDOW (fs->priv->osd),
+				 rect.width - 8 - allocation.height / 8,
+				 rect.y + 8);
+	else
+		gtk_window_move (GTK_WINDOW (fs->priv->osd), rect.x + 8, rect.y + 8);
+
+	gsd_media_keys_window_set_action_custom (GSD_MEDIA_KEYS_WINDOW (fs->priv->osd),
+						 icon_name, FALSE);
+	gtk_widget_show (fs->priv->osd);
+}
+
 G_MODULE_EXPORT gboolean
 totem_fullscreen_control_enter_notify (GtkWidget *widget,
 			       GdkEventCrossing *event,
@@ -438,6 +519,8 @@ totem_fullscreen_init (TotemFullscreen *self)
 
 	self->priv->exit_popup = GTK_WIDGET (gtk_builder_get_object (self->priv->xml,
 				"totem_exit_fullscreen_window"));
+	g_signal_connect (G_OBJECT (self->priv->exit_popup), "expose-event",
+			  G_CALLBACK (totem_fullscreen_exit_popup_expose_cb), self);
 	self->priv->control_popup = GTK_WIDGET (gtk_builder_get_object (self->priv->xml,
 				"totem_controls_window"));
 
