@@ -760,19 +760,6 @@ on_play_disc_activate (GtkAction *action, Totem *totem)
 	totem_action_play_media_device (totem, device_path);
 }
 
-/* Play DVB menu items */
-static void
-on_play_dvb_activate (GtkAction *action, Totem *totem)
-{
-	int adapter;
-	char *str;
-
-	adapter = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (action), "adapter"));
-	str = g_strdup_printf ("%d", adapter);
-	totem_action_play_media (totem, MEDIA_TYPE_DVB, str);
-	g_free (str);
-}
-
 static const char *
 get_icon_name_for_gicon (GtkIconTheme *theme,
 			 GIcon *icon)
@@ -837,8 +824,6 @@ add_mount_to_menu (GMount *mount,
 	GIcon *icon;
 	const char *icon_name;
 	char *device_path;
-	GtkWidget *menu_item;
-	char *menu_item_path;
 
 	GVolume *volume;
 	GFile *root, *iso;
@@ -914,6 +899,7 @@ add_mount_to_menu (GMount *mount,
 	action = gtk_action_new (name, label, NULL, NULL);
 	g_object_set (G_OBJECT (action),
 		      "icon-name", icon_name, NULL);
+	gtk_action_set_always_show_image (action, TRUE);
 	gtk_action_group_add_action (totem->devices_action_group, action);
 	g_object_unref (action);
 
@@ -921,14 +907,6 @@ add_mount_to_menu (GMount *mount,
 			       "/tmw-menubar/movie/devices-placeholder", name, name,
 			       GTK_UI_MANAGER_MENUITEM, FALSE);
 
-	/* TODO: This can be made cleaner once bug #589842 is fixed */
-	menu_item_path = g_strdup_printf ("/tmw-menubar/movie/devices-placeholder/%s", name);
-	menu_item = gtk_ui_manager_get_widget (totem->ui_manager, menu_item_path);
-	g_free (menu_item_path);
-
-	if (menu_item != NULL)
-		gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (menu_item), TRUE);
-
 	g_free (name);
 	g_free (label);
 	g_object_unref (icon);
@@ -1098,54 +1076,12 @@ update_drive_menu_items (GtkMenuItem *movie_menuitem, Totem *totem)
 	totem->drives_changed = FALSE;
 }
 
-static void
-update_dvb_menu_items (GtkMenuItem *movie_menuitem, Totem *totem)
-{
-	guint i;
-
-	for (i = 0 ; i < 8 ; i++) {
-		char *devicenode;
-
-		devicenode = g_strdup_printf("/dev/dvb/adapter%d/frontend0", i);
-
-		if (g_file_test (devicenode, G_FILE_TEST_EXISTS) != FALSE) {
-			char* label, *name, *adapter_name;
-			GtkAction* action;
-
-			/* translators: the index of the adapter
-			 * DVB Adapter 1 */
-			adapter_name = g_strdup_printf (_("DVB Adapter %u"), i);
-			/* translators:
-			 * Watch TV on 'DVB Adapter 1'
-			 * or
-			 * Watch TV on 'Hauppauge Nova-T Stick' */
-			label = g_strdup_printf (_("Watch TV on \'%s\'"), adapter_name);
-			g_free (adapter_name);
-			name = g_strdup_printf ("dvbdevice%d", i);
-			action = gtk_action_new (name, label, NULL, NULL);
-
-			g_object_set (G_OBJECT(action), "icon-name", "totem-tv", "sensitive", TRUE, NULL);
-			gtk_action_group_add_action (totem->devices_action_group, action);
-			g_object_unref (action);
-			gtk_ui_manager_add_ui (totem->ui_manager, totem->devices_ui_id,
-					       "/tmw-menubar/movie/devices-placeholder", name, name,
-					       GTK_UI_MANAGER_MENUITEM, FALSE);
-			g_object_set_data_full (G_OBJECT (action),
-						"adapter", GINT_TO_POINTER (i), NULL);
-			g_signal_connect (G_OBJECT (action), "activate",
-					  G_CALLBACK (on_play_dvb_activate), totem);
-		}
-		g_free (devicenode);
-	}
-}
-
 static void
 on_movie_menu_select (GtkMenuItem *movie_menuitem, Totem *totem)
 {
-	//FIXME we should check whether there's new DVB items
-/*	if (totem->drives_changed == FALSE)
+	if (totem->drives_changed == FALSE)
 		return;
-*/
+
 	/* Remove old UI */
 	gtk_ui_manager_remove_ui (totem->ui_manager, totem->devices_ui_id);
 	gtk_ui_manager_ensure_update (totem->ui_manager);
@@ -1162,10 +1098,6 @@ on_movie_menu_select (GtkMenuItem *movie_menuitem, Totem *totem)
 
 	update_drive_menu_items (movie_menuitem, totem);
 
-	/* Check for DVB */
-	/* FIXME we should only update if we have an updated as per HAL */
-	update_dvb_menu_items (movie_menuitem, totem);
-
 	gtk_ui_manager_ensure_update (totem->ui_manager);
 }
 
@@ -1581,32 +1513,6 @@ setup_menu_items (Totem *totem)
 	}
 }
 
-static const GtkActionEntry seek_entries_ltr[] = {
-	{ "skip-forward", GTK_STOCK_MEDIA_FORWARD, N_("Skip _Forward"), "Right", N_("Skip forward"), G_CALLBACK (skip_forward_action_callback) },
-	{ "skip-backwards", GTK_STOCK_MEDIA_REWIND, N_("Skip _Backwards"), "Left", N_("Skip backwards"), G_CALLBACK (skip_backwards_action_callback) }
-};
-
-static const GtkActionEntry seek_entries_rtl[] = {
-	{ "skip-forward", GTK_STOCK_MEDIA_FORWARD, N_("Skip _Forward"), "Left", N_("Skip forward"), G_CALLBACK (skip_forward_action_callback) },
-	{ "skip-backwards", GTK_STOCK_MEDIA_REWIND, N_("Skip _Backwards"), "Right", N_("Skip backwards"), G_CALLBACK (skip_backwards_action_callback) }
-};
-
-static const GtkToggleActionEntry toggle_entries[] = {
-	{ "repeat-mode", NULL, N_("_Repeat Mode"), NULL, N_("Set the repeat mode"), G_CALLBACK (repeat_mode_action_callback), FALSE },
-	{ "shuffle-mode", NULL, N_("Shuff_le Mode"), NULL, N_("Set the shuffle mode"), G_CALLBACK (shuffle_mode_action_callback), FALSE },
-	{ "deinterlace", NULL, N_("_Deinterlace"), "I", N_("Deinterlace"), G_CALLBACK (deinterlace_action_callback), FALSE },
-	{ "show-controls", NULL, N_("Show _Controls"), "H", N_("Show controls"), G_CALLBACK (show_controls_action_callback), TRUE },
-	{ "sidebar", NULL, N_("S_idebar"), "F9", N_("Show or hide the sidebar"), G_CALLBACK (show_sidebar_action_callback), TRUE }
-};
-
-static const GtkRadioActionEntry aspect_ratio_entries[] = {
-	{ "aspect-ratio-auto", NULL, N_("Auto"), NULL, N_("Sets automatic aspect ratio"), BVW_RATIO_AUTO },
-	{ "aspect-ratio-square", NULL, N_("Square"), NULL, N_("Sets square aspect ratio"), BVW_RATIO_SQUARE },
-	{ "aspect-ratio-fbt", NULL, N_("4:3 (TV)"), NULL, N_("Sets 4:3 (TV) aspect ratio"), BVW_RATIO_FOURBYTHREE },
-	{ "aspect-ratio-anamorphic", NULL, N_("16:9 (Widescreen)"), NULL, N_("Sets 16:9 (Anamorphic) aspect ratio"), BVW_RATIO_ANAMORPHIC },
-	{ "aspect-ratio-dvb", NULL, N_("2.11:1 (DVB)"), NULL, N_("Sets 2.11:1 (DVB) aspect ratio"), BVW_RATIO_DVB }
-};
-
 void
 totem_ui_manager_setup (Totem *totem)
 {
@@ -1615,15 +1521,14 @@ totem_ui_manager_setup (Totem *totem)
 
 	/* FIXME: Moving these to GtkBuilder depends on bug #457631 */
 	if (gtk_widget_get_direction (totem->win) == GTK_TEXT_DIR_RTL) {
-		GList *actions = NULL;
 		GtkActionGroup *action_group = GTK_ACTION_GROUP (gtk_builder_get_object (totem->xml, "skip-action-group"));
+		GtkAction *action;
 
-		for (actions = gtk_action_group_list_actions (action_group); actions != NULL; actions = actions->next)
-			gtk_action_group_remove_action (action_group, GTK_ACTION (actions->data));
+		action = gtk_action_group_get_action (action_group, "skip-forward");
+		gtk_action_set_accel_path (action, "Left");
 
-		gtk_action_group_add_actions (action_group,
-				seek_entries_rtl,
-				G_N_ELEMENTS (seek_entries_rtl), totem);
+		action = gtk_action_group_get_action (action_group, "skip-backwards");
+		gtk_action_set_accel_path (action, "Right");
 	}
 
 	totem->ui_manager = GTK_UI_MANAGER (gtk_builder_get_object (totem->xml, "totem-ui-manager"));
