@@ -397,16 +397,33 @@ totem_playlist_update_save_button (TotemPlaylist *playlist)
 	gtk_widget_set_sensitive (button, state);
 }
 
-static void
-totem_playlist_save_get_iter_func (GtkTreeModel *model,
-		GtkTreeIter *iter, char **uri, char **title,
-		gboolean *custom_title, gpointer user_data)
+static gboolean
+totem_playlist_save_iter_foreach (GtkTreeModel *model,
+				  GtkTreePath  *path,
+				  GtkTreeIter  *iter,
+				  gpointer      user_data)
 {
+	TotemPlPlaylist *playlist = user_data;
+	TotemPlPlaylistIter pl_iter;
+	gchar *uri, *title;
+	gboolean custom_title;
+
 	gtk_tree_model_get (model, iter,
-			URI_COL, uri,
-			FILENAME_COL, title,
-			TITLE_CUSTOM_COL, custom_title,
-			-1);
+			    URI_COL, &uri,
+			    FILENAME_COL, &title,
+			    TITLE_CUSTOM_COL, &custom_title,
+			    -1);
+
+	totem_pl_playlist_append (playlist, &pl_iter);
+	totem_pl_playlist_set (playlist, &pl_iter,
+			       TOTEM_PL_PARSER_FIELD_URI, uri,
+			       TOTEM_PL_PARSER_FIELD_TITLE, (custom_title) ? title : NULL,
+			       NULL);
+
+	g_free (uri);
+	g_free (title);
+
+	return FALSE;
 }
 
 void
@@ -418,13 +435,22 @@ totem_playlist_save_current_playlist (TotemPlaylist *playlist, const char *outpu
 void
 totem_playlist_save_current_playlist_ext (TotemPlaylist *playlist, const char *output, TotemPlParserType type)
 {
+	TotemPlPlaylist *pl_playlist;
 	GError *error = NULL;
+	GFile *output_file;
 	gboolean retval;
 
-	retval = totem_pl_parser_write (playlist->priv->parser,
-			playlist->priv->model,
-                        totem_playlist_save_get_iter_func,
-			output, type, NULL, &error);
+	pl_playlist = totem_pl_playlist_new ();
+	output_file = g_file_new_for_commandline_arg (output);
+
+	gtk_tree_model_foreach (playlist->priv->model,
+				totem_playlist_save_iter_foreach,
+				pl_playlist);
+
+	retval = totem_pl_parser_save (playlist->priv->parser,
+				       pl_playlist,
+				       output_file,
+				       NULL, type, &error);
 
 	if (retval == FALSE)
 	{
@@ -432,6 +458,9 @@ totem_playlist_save_current_playlist_ext (TotemPlaylist *playlist, const char *o
 				error->message, playlist);
 		g_error_free (error);
 	}
+
+	g_object_unref (pl_playlist);
+	g_object_unref (output_file);
 }
 
 static void
@@ -1304,6 +1333,51 @@ treeview_row_changed (GtkTreeView *treeview, GtkTreePath *arg1,
 	}
 }
 
+static gboolean
+search_equal_is_match (const gchar * s, const gchar * lc_key)
+{
+	gboolean match = FALSE;
+
+	if (s != NULL) {
+		gchar *lc_s;
+
+		/* maybe also normalize both strings? */
+		lc_s = g_utf8_strdown (s, -1);
+		match = (lc_s != NULL && strstr (lc_s, lc_key) != NULL);
+		g_free (lc_s);
+	}
+
+	return match;
+}
+
+static gboolean
+search_equal_func (GtkTreeModel *model, gint col, const gchar *key,
+                   GtkTreeIter *iter, gpointer userdata)
+{
+	gboolean match;
+	gchar *lc_key, *fn = NULL;
+
+	lc_key = g_utf8_strdown (key, -1);
+
+        /* type-ahead search: first check display filename / title, then URI */
+	gtk_tree_model_get (model, iter, FILENAME_COL, &fn, -1);
+	match = search_equal_is_match (fn, lc_key);
+	g_free (fn);
+
+	if (!match) {
+		gchar *uri = NULL;
+
+		gtk_tree_model_get (model, iter, URI_COL, &uri, -1);
+		fn = g_filename_from_uri (uri, NULL, NULL);
+		match = search_equal_is_match (fn, lc_key);
+		g_free (fn);
+		g_free (uri);
+	}
+
+	g_free (lc_key);
+	return !match; /* needs to return FALSE if row matches */
+}
+
 static void
 init_treeview (GtkWidget *treeview, TotemPlaylist *playlist)
 {
@@ -1340,6 +1414,10 @@ init_treeview (GtkWidget *treeview, TotemPlaylist *playlist)
 
 	playlist->priv->selection = selection;
 
+	/* make type-ahead search work in the playlist */
+	gtk_tree_view_set_search_equal_func (GTK_TREE_VIEW (treeview),
+	                                     search_equal_func, NULL, NULL);
+
 	gtk_widget_show (treeview);
 }
 
